Coverage for jacc/forms.py: 100%

# Coverage for jacc/forms.py : 100%

## 7 statements 7 run 0 missing 0 excluded

Hot-keys on this page

r m x p toggle line displays

j k next/prev highlighted chunk

0 (zero) top of page

1 (one) first highlighted chunk

1 from django import forms

2 from django.utils.timezone import now

3 from django.utils.translation import gettext_lazy as _

4

5

6 class ReverseChargeForm(forms.Form):

7 timestamp = forms.DateTimeField(label=_('timestamp'), required=True, initial=now)

8 amount = forms.DecimalField(label=_('amount'), required=True, decimal_places=2, max_digits=10)

9 description = forms.CharField(label=_('description'), max_length=128, required=True, widget=forms.Textarea,

10 initial=_('reverse.charge.form.default.description'))